PopupState

Struct PopupState 

pub struct PopupState { /* private fields */ }

Implementations

Source

impl PopupState

Auto-generated by derive_getters::Getters.

pub fn area(&self) -> &Option<Rect>

The last rendered area of the popup

Examples found in repository?
examples/state.rs (line 76)
75fn render_status_bar(frame: &mut Frame, area: Rect, state: &PopupState) {
76    let popup_area = state.area().unwrap_or_default();
77    let text = format!("Popup area: {popup_area:?}");
78    let paragraph = Paragraph::new(text).style(Style::new().white().on_black());
79    frame.render_widget(paragraph, area);
80}
pub fn drag_state(&self) -> &DragState

A state indicating whether the popup is being dragged or not

Source

impl PopupState

pub fn move_up(&mut self, amount: u16)

Examples found in repository?
examples/state.rs (line 97)
92fn handle_key_event(event: KeyEvent, popup: &mut PopupState, exit: &mut bool) {
93    match event.code {
94        KeyCode::Char('q') | KeyCode::Esc => *exit = true,
95        KeyCode::Char('r') => *popup = PopupState::default(),
96        KeyCode::Char('j') | KeyCode::Down => popup.move_down(1),
97        KeyCode::Char('k') | KeyCode::Up => popup.move_up(1),
98        KeyCode::Char('h') | KeyCode::Left => popup.move_left(1),
99        KeyCode::Char('l') | KeyCode::Right => popup.move_right(1),
100        _ => {}
101    }
102}
pub fn move_down(&mut self, amount: u16)

Examples found in repository?
examples/state.rs (line 96)
92fn handle_key_event(event: KeyEvent, popup: &mut PopupState, exit: &mut bool) {
93    match event.code {
94        KeyCode::Char('q') | KeyCode::Esc => *exit = true,
95        KeyCode::Char('r') => *popup = PopupState::default(),
96        KeyCode::Char('j') | KeyCode::Down => popup.move_down(1),
97        KeyCode::Char('k') | KeyCode::Up => popup.move_up(1),
98        KeyCode::Char('h') | KeyCode::Left => popup.move_left(1),
99        KeyCode::Char('l') | KeyCode::Right => popup.move_right(1),
100        _ => {}
101    }
102}
pub fn move_left(&mut self, amount: u16)

Examples found in repository?
examples/state.rs (line 98)
92fn handle_key_event(event: KeyEvent, popup: &mut PopupState, exit: &mut bool) {
93    match event.code {
94        KeyCode::Char('q') | KeyCode::Esc => *exit = true,
95        KeyCode::Char('r') => *popup = PopupState::default(),
96        KeyCode::Char('j') | KeyCode::Down => popup.move_down(1),
97        KeyCode::Char('k') | KeyCode::Up => popup.move_up(1),
98        KeyCode::Char('h') | KeyCode::Left => popup.move_left(1),
99        KeyCode::Char('l') | KeyCode::Right => popup.move_right(1),
100        _ => {}
101    }
102}
pub fn move_right(&mut self, amount: u16)

Examples found in repository?
examples/state.rs (line 99)
92fn handle_key_event(event: KeyEvent, popup: &mut PopupState, exit: &mut bool) {
93    match event.code {
94        KeyCode::Char('q') | KeyCode::Esc => *exit = true,
95        KeyCode::Char('r') => *popup = PopupState::default(),
96        KeyCode::Char('j') | KeyCode::Down => popup.move_down(1),
97        KeyCode::Char('k') | KeyCode::Up => popup.move_up(1),
98        KeyCode::Char('h') | KeyCode::Left => popup.move_left(1),
99        KeyCode::Char('l') | KeyCode::Right => popup.move_right(1),
100        _ => {}
101    }
102}
pub fn move_by(&mut self, x: i32, y: i32)

Move the popup by the given amount.

pub const fn move_to(&mut self, x: u16, y: u16)

Move the popup to the given position.

pub fn mouse_down(&mut self, col: u16, row: u16)

Set the state to dragging if the mouse click is in the popup title

pub const fn mouse_up(&mut self, _col: u16, _row: u16)

Set the state to not dragging

pub const fn mouse_drag(&mut self, col: u16, row: u16)

Move the popup if the state is dragging

pub fn handle_mouse_event(&mut self, event: MouseEvent)

Examples found in repository?
examples/state.rs (line 87)
82fn handle_events(popup: &mut PopupState, exit: &mut bool) -> Result<()> {
83    let event = event::read()?;
84    if let Some(key) = event.as_key_press_event() {
85        handle_key_event(key, popup, exit);
86    } else if let Event::Mouse(event) = event {
87        popup.handle_mouse_event(event);
88    }
89    Ok(())
90}